@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0803';
+our $VERSION = '0.0804';
 
 use Moo;
 use strictures 2;
@@ -195,9 +195,9 @@ sub motifs {
 
 
 sub add_to_score {
-    my ($self, $score, $motif, $notes) = @_;
+    my ($self, $score, $motif, $pitches) = @_;
     for my $i (0 .. $#$motif) {
-        $score->n($motif->[$i], $notes->[$i]);
+        $score->n($motif->[$i], $pitches->[$i]);
     }
 }
 
@@ -230,7 +230,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0803
+version 0.0804
 
 =head1 SYNOPSIS
 
@@ -239,7 +239,6 @@ version 0.0803
   my $mdp = Music::Duration::Partition->new(
     size => 8,                  # 2 measures in 4/4 time
     pool => [qw(hn dqn qn en)], # Made from these durations
-    pool_select => sub { my $self = shift; ... }, # optional
   );
 
   # the pool may also be weighted
@@ -390,9 +389,9 @@ Return B<n> motifs.
 
 =head2 add_to_score
 
-  $mdp->add_to_score($score, $motif, $notes);
+  $mdp->add_to_score($score, $motif, $pitches);
 
-Return B<n> motifs.
+Add the B<motif> and B<pitches> to the B<score>.
 
 =head1 SEE ALSO
 
